==> KleckFiles(4.07.00).zip: KleckFiles/html/kjv/vcvdata.js <==
// List of bible books > list of chapters and verses containing vids
// Run lego.html -- CTRL+Click the Home LOGO in the header

var __VideoCVData = [
// Genesis
[
[1, [26,27,0,7,1,2]], [2, [0,7,1,2,18,19]], [3, [3,0,6,21]], [4, [1]], [6, [3,4]], [7, [2]], [14, [18]], [15, [0]]
],
// Exodus
[
[20, [0,4,2]]
],
// Leviticus
[
],
// Numbers
[
],
// Deuteronomy
[
],
// Joshua
[
],
// Judges
[
],
// Ruth
[
],
// 1 Samuel
[
[15, [23]], [17, [0]]
],
// 2 Samuel
[
],
// 1 Kings
[
],
// 2 Kings
[
],
// 1 Chronicles
[
],
// 2 Chronicles
[
],
// Ezra
[
],
// Nehemiah
[
],
// Esther
[
],
// Job
[
[8, [0]]
],
// Psalm
[
[8, [0,5]], [18, [0]], [22, [0]], [23, [1,0]], [35, [0,15,19]], [46, [0]], [47, [4,2]], [68, [16]], [82, [5,0,1,6]], [103, [0,12]], [122, [0]], [146, [9]]
],
// Proverbs
[
[2, [2]], [25, [2,0]]
],
// Ecclesiastes
[
],
// Song of Solomon
[
],
// Isaiah
[
[1, [18]], [6, [0,10]], [7, [14,13]], [12, [2,0]], [13, [0]], [14, [0,13,12,1]], [24, [6,0,17,18]], [28, [15]], [29, [0,15,16]], [30, [0]], [35, [0,19]], [40, [0]], [42, [22,0,24]], [43, [10,12,0,11,3]], [44, [8]], [45, [7,3,0,5]], [54, [0,9]], [57, [4]], [61, [0,10,1]]
],
// Jeremiah
[
[1, [0]], [29, [0]], [46, [20]], [51, [60,63,1]]
],
// Lamentations
[
],
// Ezekiel
[
[7, [0,7]], [12, [0]], [13, [0,20,18,13]], [28, [2,12,0,14,16]], [33, [6]], [34, [17]]
],
// Daniel
[
[2, [44,0,43,41]], [12, [0,1,5]]
],
// Hosea
[
],
// Joel
[
[2, [25]]
],
// Amos
[
],
// Obadiah
[
],
// Jonah
[
],
// Micah
[
],
// Nahum
[
],
// Habakkuk
[
[2, [0,2]], [3, [9,13,0,14]]
],
// Zephaniah
[
],
// Haggai
[
],
// Zechariah
[
],
// Malachi
[
],
// Matthew
[
[3, [11]], [4, [8]], [6, [22,0]], [7, [0,3]], [10, [16]], [12, [30,25,0]], [13, [13]], [16, [0,13]], [18, [3]], [21, [11,12]], [24, [0]], [25, [31]], [27, [0,45]]
],
// Mark
[
[1, [15,0]], [9, [40,47,46]], [14, [0]]
],
// Luke
[
[4, [18,16]], [6, [0]], [9, [50]], [10, [18]], [11, [34,54]], [21, [25,28,16,36]], [23, [0]]
],
// John
[
[3, [16,3,5,0]], [8, [0,44,32]], [10, [34,31,1,0]], [11, [25]], [15, [18,20,22,25]], [17, [3,1]]
],
// Acts
[
[17, [6]], [20, [29]], [26, [0]]
],
// Romans
[
[8, [21,20,0]]
],
// 1 Corinthians
[
[2, [0,3,7,2,14,4]], [3, [15]], [12, [0]], [15, [45,35,44,43,0]]
],
// 2 Corinthians
[
[4, [0]]
],
// Galatians
[
[4, [16]], [5, [9,0]]
],
// Ephesians
[
[2, [0,5,14,15,1,2]], [5, [11,14]], [6, [12]]
],
// Philippians
[
[3, [8,14,10,0]]
],
// Colossians
[
[1, [23]], [2, [0,14,15]], [3, [3]]
],
// 1 Thessalonians
[
],
// 2 Thessalonians
[
],
// 1 Timothy
[
[3, [9]]
],
// 2 Timothy
[
[2, [25,21,3,15,0]]
],
// Titus
[
],
// Philemon
[
],
// Hebrews
[
[1, [7]], [11, [0]], [12, [0]]
],
// James
[
[1, [17,18]], [4, [8]]
],
// 1 Peter
[
[1, [17]], [2, [11,9,2,7]], [5, [8]]
],
// 2 Peter
[
[2, [4]]
],
// 1 John
[
[4, [3]], [5, [19]]
],
// 2 John
[
],
// 3 John
[
],
// Jude
[
[1, [6,5]]
],
// Revelation
[
[1, [3,0]], [3, [10,12,8,0,7]], [6, [2,3,5]], [9, [11,5,0,7,1,3]], [12, [9,7]], [13, [0,16,15,14]], [17, [4,6]], [21, [0]], [22, [3,0,2]]
],
// Acts of Peter
[
],
// Targum Genesis
[
]
];

==> KleckFiles(4.45.00).zip: KleckFiles/html/kjv/vcvdata.js <==
// List of bible books > list of chapters and verses containing vids
// Run lego.html -- CTRL+Click the Home LOGO in the header

// List of bible books > list of chapters and verses containing vids
// Run lego.html -- CTRL+Click the Home LOGO in the header

var __VideoCVData = [
// Genesis
[
[1, [27,26,0,7,1,2]], [2, [0,7,1,2,18,19]], [3, [3,0,6,21]], [4, [0,1]], [6, [3,4]], [7, [2]], [14, [18]], [15, [0]]
],
// Exodus
[
[20, [0,4,2]]
],
// Leviticus
[
],
// Numbers
[
],
// Deuteronomy
[
],
// Joshua
[
],
// Judges
[
],
// Ruth
[
],
// 1 Samuel
[
[15, [23]], [17, [0]]
],
// 2 Samuel
[
],
// 1 Kings
[
],
// 2 Kings
[
],
// 1 Chronicles
[
],
// 2 Chronicles
[
],
// Ezra
[
],
// Nehemiah
[
],
// Esther
[
],
// Job
[
[8, [0]]
],
// Psalm
[
[8, [0,5]], [18, [0]], [22, [0]], [23, [1,0]], [35, [19,0,15]], [46, [0]], [47, [4,2]], [68, [16]], [82, [5,0,1,6]], [103, [0,12]], [122, [0]], [146, [9]]
],
// Proverbs
[
[2, [2]], [25, [2,0]]
],
// Ecclesiastes
[
],
// Song of Solomon
[
],
// Isaiah
[
[1, [18]], [6, [0,10]], [7, [14,13]], [12, [2,0]], [13, [0]], [14, [0,13,12,1]], [24, [6,0,17,18]], [28, [15]], [29, [0,15,16]], [30, [0]], [34, [0,5,3]], [35, [0,19]], [40, [0]], [42, [22,0,24]], [43, [10,12,0,11,3]], [44, [8]], [45, [7,3,0,5]], [49, [24]], [54, [0,9]], [57, [4]], [61, [0,10,1]]
],
// Jeremiah
[
[1, [0]], [29, [0]], [46, [20]], [51, [60,63,1]]
],
// Lamentations
[
],
// Ezekiel
[
[7, [0,7]], [12, [0]], [13, [0,20,18,13]], [28, [2,12,0,14,16]], [33, [6]], [34, [17]]
],
// Daniel
[
[2, [44,0,43,41]], [12, [0,1,5]]
],
// Hosea
[
],
// Joel
[
[2, [25]]
],
// Amos
[
],
// Obadiah
[
],
// Jonah
[
],
// Micah
[
],
// Nahum
[
],
// Habakkuk
[
[2, [0,2]], [3, [9,13,0,14]]
],
// Zephaniah
[
],
// Haggai
[
],
// Zechariah
[
],
// Malachi
[
],
// Matthew
[
[3, [11]], [4, [6,8]], [6, [22,0]], [7, [0,3]], [10, [16]], [12, [30,25,0]], [13, [13]], [16, [0,13]], [18, [3]], [21, [11,12]], [24, [0]], [25, [31]], [27, [0,45]]
],
// Mark
[
[1, [15,0]], [9, [40,47,46]], [14, [0]]
],
// Luke
[
[4, [18,16]], [6, [0]], [9, [50]], [10, [18]], [11, [34,54]], [21, [25,28,16,36]], [23, [0]]
],
// John
[
[3, [16,3,5,0]], [8, [0,44,32]], [10, [34,31,1,0]], [11, [25]], [15, [18,20,22,25]], [17, [3,1]]
],
// Acts
[
[17, [6]], [20, [29]], [26, [0]]
],
// Romans
[
[8, [21,20,0]]
],
// 1 Corinthians
[
[2, [0,3,7,2,14,4]], [3, [15]], [12, [0]], [15, [45,35,44,43,0]]
],
// 2 Corinthians
[
[4, [0]]
],
// Galatians
[
[4, [16]], [5, [9,0]]
],
// Ephesians
[
[2, [2,0,5,14,15,1]], [5, [11,14]], [6, [12]]
],
// Philippians
[
[3, [8,14,10,0]]
],
// Colossians
[
[1, [23]], [2, [0,14,15]], [3, [3]]
],
// 1 Thessalonians
[
],
// 2 Thessalonians
[
],
// 1 Timothy
[
[3, [9]]
],
// 2 Timothy
[
[2, [25,21,3,15,0]]
],
// Titus
[
],
// Philemon
[
],
// Hebrews
[
[1, [7]], [11, [0]], [12, [0]]
],
// James
[
[1, [17,18]], [4, [8]]
],
// 1 Peter
[
[1, [17]], [2, [11,9,2,7]], [5, [8]]
],
// 2 Peter
[
[2, [4]]
],
// 1 John
[
[4, [3]], [5, [19]]
],
// 2 John
[
],
// 3 John
[
],
// Jude
[
[1, [6,5]]
],
// Revelation
[
[1, [3,0]], [3, [10,12,8,0,7]], [6, [2,3,5]], [9, [7,11,5,0,1,3]], [12, [9,7]], [13, [0,16,15,14]], [17, [4,6]], [21, [0]], [22, [3,0,2]]
],
// Acts of Peter
[
],
// Targum Genesis
[
]
];
